import java.io.BufferedReader;
import com.etantdonnes.tinyos.*;
import com.etantdonnes.tinyos.UPIC.*;

public class UPComm extends TOSComm
{
	/** main execution
	 *   creates a Message Factory and runs TOSComm
	 *   override to make your own
	 * 
	 * @param args
	 * @throws Exception
	 */
	public static void main(String args[]) throws Exception
	{
		try
		{
			// get my xxComm object
			//  sets TOSComm "global" String programName
			TOSComm tc = new UPComm();
			
			// parse args and get an input stream
			BufferedReader in = tc.parseArgs( args );
			
			// get my TOS connection and Message Factory
			//  uses MOTECOM environment variable to find port and type
			TMfactory mf = new myTMfactory(); // recv msg factory
			
			// execute input function interpreter
			System.out.println( "starting " + programName );
			tc.execute( mf, in );
			System.out.println( programName + " done" );
		
		} catch( Exception e )
		{
			System.err.println( programName + " Error initializing" +
								" -- " + e.toString() +
								" : " + e.getMessage() );
		}	
		
		System.exit(0);
	} // end'o'main
		
	
	/** do setup before anything executes
	 *   like changing default names and stuff
	 */
	protected void setUp()
	{
		// our program name
		programName = "UPComm";
		// get/save file name
		DefaultFile = "UPsave.txt";
		return;
	}

} // end'o'UPComm

/** Application class for TOS_Msg communications
 *   Define the extended message we want to create
**/
class myTMfactory extends TMfactory
{
    // RoboCar Status message type (Send to Host)
    public static final int AM_ROBOSTATUSMSG = 10;
    
	/** Create a factory for our TOSMSG header type
	 *   as specified in MOTECOM variable read by PacketSource.
	 */
	public myTMfactory() throws Exception
	{
		super();
	}
	
	/** Create a factory for our TOSMSG header type.
	 *   First try the t argument to force a specific header type,
	 *   if failed try the ps argument to get the MOTECOM type.
	 * 
	 * @param ps -- Packet source will contain the MOTECOM type
	 * @param t  -- Force specific type, mostly for extended headers,
	 * 				 Values are defined in TOS_Msg, or use -1 for none.
	public myTMfactory( PacketSource ps, int t ) throws Exception
	{
		super( ps, t );
	}
	 */
	
	/** Create a Message class of the right kind for the given type.
	 *   Switch on the message AM types to be expected.
	 *   If none found then call the default impl to make
	 *    stub for the underlying struct.
	 */
	@SuppressWarnings("unchecked")
	public TOS_Msg makeMessage( int AMtype )
	{
		/**/
		if( AMtype == 2 )
		{
			// UPIC int message
			return new TMUPICint();
		}
		if( (AMtype == 10) )
		{
			// UPIC 4-byte format message
			return new TMUPIC4byte();
		}
		if( (AMtype == 12) || (AMtype == 13) )
		{
			// UPIC short integer data format message
			return new TMUPICdata();
		}
		/**/
		/*
		if( AMtype == Oscope1000Msg.AM_OSCOPEMSG )
		{
			// Oscilloscope message
			return new Oscope1000Msg();
		}
		else if( AMtype == CPMsg.CPAM_DATAMSG )
		{
			// data message
			return new CPdataMsg();
		}
		else if( AMtype == CPMsg.CPAM_CALIBMSG )
		{
			// calibration results message
			return new CPcalibMsg();
		}
		*/
		
		return super.makeMessage( AMtype );
	}
	
	/** Do something with the current received message 
	 *    default just sets curMsg for getMessage() to return
	 *   ...extend to do something useful...
	 */
    @SuppressWarnings("unchecked")
	synchronized public void doMessage( TOS_Msg msg )
    {
		super.doMessage( msg );
    }
    
} // end'o'myTMfactory
