/** MessageLogOne.java -- Logging routines for single message tests
**/
package com.etantdonnes.tinyos;

import java.io.PrintStream;

@SuppressWarnings("unchecked")
public class MessageLogOne implements MessageLog
{
	// set true to print full class name in log
	static final boolean printclass = false;
	static boolean printHeader = false;
	
	protected PrintStream out = null;	// output stream
	
	/** Make a logger thing that prints basic message data
	 * @param doPreamble -- true to print header and suchlike
	 *                      false to just print message payload
	 * @param o -- output stream to use, nominally System.out
	 * 
	 */
	public MessageLogOne( boolean doPreamble, PrintStream o )
	{
		super();
		out = o;
		printHeader = doPreamble;
	}

	/* (non-Javadoc)
	 * @see com.etantdonnes.tinyos.robo.LogMessage#startLog()
	 */
	public void startLog()
	{
		// TODO: Nothing
	}

	/* (non-Javadoc)
	 * @see com.etantdonnes.tinyos.robo.LogMessage#stopLog()
	 */
	public void stopLog()
	{
		// TODO: Nothing
	}

	/* (non-Javadoc)
	 * @see com.etantdonnes.tinyos.robo.LogMessage#
	 *  logWrite(long, boolean, com.etantdonnes.tinyos.robo.RoboStatReq)
	 */
	public void logWrite( TOS_Msg msg )
	{
		if( printHeader )
			out.print( "TX: " + msgClass( msg ) + " = " );
		
		out.println(  msg.toString() );
	}
		
	/* (non-Javadoc)
	 * @see com.etantdonnes.tinyos.robo.LogMessage#
	 *  logRead(com.etantdonnes.tinyos.robo.RoboStatMsg)
	 */
	public void logRead( TOS_Msg msg )
	{
		if( printHeader )
			out.print( "RX: " + msgClass( msg ) + " = " );
		
		out.println( msg.toString() );
	}

	// return the message class name,
	//  full or just class depending on "printclass" setting
	protected String msgClass( TOS_Msg msg )
	{
		String cname = msg.getClass().toString();
		
		if( !printclass )
		{
			int idx = cname.lastIndexOf( "." );
			if( idx != -1 )
				cname = cname.substring( idx+1 );
		}
		
		return cname;
	}
} // end'o'MessageLogOne
