/** TMMXmsgtype.java -- Xbow XMesh message type defines
 *   shared between all XMESH messages.
 */
package com.etantdonnes.tinyos;

public class TMMXmsgtype
{
	/** The defined message AM types in the TOS_Msg header
	 *   DATA2BASE and DATA2NODE (and their ACK versions are for
	 *    user data transport and expect to have an XMEsh header
	 *    with the "socket" field set to the user message type.
	 *    
	 *   By examination the following messages have no XMesh header
	 *    when received from the basestation at the host:
	 *		AM_HEARTBEAT
	 */
	public final static int AM_HEALTH = 3; //  Reserved for Health packets from the mote 
	public final static int AM_DATA2BASE = 11; // Upstream data msg from node to base, no ack 
	public final static int AM_DATA2NODE = 12; //  Downstream data to node 
	public final static int AM_DATAACK2BASE = 13; //  Upstream guaranteed delivery to base 
	public final static int AM_DATAACK2NODE = 14; //  Downstream guaranteed delivery to node 
	public final static int AM_ANY2ANY = 15; //  Any to any  
	public final static int AM_MGMT = 90; //  OTAP status message 
	public final static int AM_BULKXFER = 91; // OTAP transfer fragment 
	public final static int AM_MGMTRESP = 92; //  OTAP status acknowledgement 
	public final static int AM_TIMESYNC = 239; // Time Sync packet 
	public final static int AM_PREAMBLE = 240; //  Low power preamble packet 
	public final static int AM_FASTJOIN = 241; // Fast join 
	public final static int AM_FASTJOINRESP = 242; // Fast join 
	public final static int AM_DOWNSTREAM_ACK = 246; //  Ack message from base to node 
	public final static int AM_UPSTREAM_ACK = 247; //  Ack message from node to base 
	public final static int AM_PATH_LIGHT_DOWN = 248; //  Light full power path down to node 
	public final static int AM_PATH_LIGHT_UP = 249; //  Light full power path up to base 
	public final static int AM_MULTIHOPMSG = 250; //  Route update message 
	public final static int MODE_ONE_HOP_BROADCAST = 251; //  Single-hop service via XMesh 
	public final static int AM_HEARTBEAT = 253; //  Base station heart beat message 

}
