/* TMstub1000.java --
 *  Generic stub message for CC1000 "mica2"
 *    and "micaz" serial type TOS Messages.
 * 
 * Created on Jun 25, 2009
 * Rewanked April 2012
 */
package com.etantdonnes.tinyos;


public class TMstub1000 extends TOS_Msg<TMheader1000>
{
	// payload bytes in this packet (default)
	public static final int PAYSIZE = TMheader1000.PAYSIZE;
	// number of parameters in message (single bytes)
	private static final int NUMFIELDS = PAYSIZE;

	/** Create a message with empty values
	 *    usually for received message wrapper
	 */
	public TMstub1000()
	{
		super( new TMheader1000() );
	}

	/** Create a message with specified parameters
	 * 		usually for extended send message
	 * @param type	-- message AM type
	 * @param len	-- message payload length
	 * @param dest  -- destination mote ID or -1 for broadcast
	 * @param gid	-- groupID
	 */
	public TMstub1000( int type, int len, int dest, int gid )
	{
		super( new TMheader1000( type, len, dest, gid ) );
	}

 /**** NOTE: all the offsets and sizes of message elements are
  ****  hard coded here...for the STUB we just use the defaults
  ****	override and add message parsing in sub-classes
  ****  as described in TOS_Msg base class
  ****   e.g. also see CountMsg and Oscope1000Msg
  ****/
	
 /**** Utilities to override in sub-classes to change the
  ****   parsing and printing behavior, instead of overriding
  ****   methods for simple format changes.
  ****/
	
	/** Set the format of data buffer interpretation.
	 *   So we don't have to override the actual methods to
	 *    switch between simple data array formats...
	 *   Default to unsigned bytes...
	 *  @return -- any of the helpParse.FORMATS
	protected int getFieldFormat() { return helpParse.UNSIGNEDSHORT; }
	 */
	
	/** Set the format of printed lines in toString().
	 *  Also uses getFieldFormat() to find size of each element
	 *   and [un]signed format.
	 *  Default to eight hex bytes per line...
	 */
	/**  @return -- number of elements to print on a line
	protected int getFieldsPerLine() { return 8; }
	 */

	/**  @return -- print conversion base: 10 or 16
	protected int getPrintBase() { return 10; }
	 */

	/**  @return -- toString() print class and header if true
	protected boolean printHeader() { return true; }
	 */
	
	/** Return the max number of fields we can set/get in this message
	 *  Note: that this needs to be defined and executed in the
	 *   final message classes in order to get the right numbers.
	 *  
	 * @return number of message fields
	**/
	public int getNumFields() { return NUMFIELDS; }
	
	/** Parse the data buffer message packet into our local fields.
	 *   Prepare received data buffer for access...
	 * @return -- number of bytes parsed (next byte position in buffer)
	 * 			  or -1 on errors
	protected int parseMessage()
	{
	}
	 */
	
	/** Copy the local field values into a returned int array
	 *  This copies directly from local data buffer,
	 *   interpreting it as defined by getFieldFormat().
	 *   
	 *  Override to use different buffer,
	 *   or more complicated data structures.
	 *   
	 * @return array of fields of length relative to data buffer size
	 *           (nominally NUMFIELDS, but based on actual size)
	 *         or null if no data
	public int[] getFields()
	{
	}
	**/
	
	/** Set local fields into our data buffer.
	 *  Prepare local data buffer for send.
	 * @return -- number of bytes set (next byte position in buffer)
	 * 			  or -1 on errors
	protected int setMessage()
	{
	}
	 **/
	
	/** Set the local field values from given array.
	 *  This copies the given vals directly into alloced data buffer,
	 *   interpreting them as defined by getFieldFormat().
	 *  Over ride as seen fit.
	 * @return nada
	public void setFields( int[] vals )
	{
	}
	**/

	/** Utility to set the local field values to the don't-care value
	 *   Possibly 0 or -1...implement as needed...
	 * @return nada
	public void nullFields() {  }
	**/

} // end'o'TMstub1000.java
	