/* TMUPICint.java --
 *  Integer message for schip's USBPIC type TOS Messages.
 *  Uses all the default impls in TOS_Msg and UPICstub, but
 *  Interprets and Prints message as two byte unsigned hex values.
 * 
 * Created on May 16, 2011
 * Rewanked on April Fools 2012
 */
package com.etantdonnes.tinyos.UPIC;

import com.etantdonnes.tinyos.*;

public class TMUPICint extends TMstubUPIC
{
	// maximum number of 2 byte integer parameters in message
	private static final int NUMFIELDS = TMheaderUPIC.PAYSIZE/2;

	/** Create a message with empty values
	 *    usually for received message wrapper
	 */
	public TMUPICint()
	{
		super();
	}
	
	/** Create a message with specified type and size
	 * 		for generic send messages and extenders
	 *  	  group ID default to 0, not used in this impl
	 * @param type	-- user message type
	 * @param len	-- user message payload length
	 */
	public TMUPICint( int type, int len )
	{
		super( type, len );
	}

 /**** Utilities to override in sub-classes to change the
  ****   parsing and printing behavior, instead of overriding
  ****   methods for simple format changes.
  ****/
	
	/** Set the format of data buffer interpretation.
	 *   So we don't have to override the actual methods to
	 *    switch between simple data array formats...
	 *   Default to unsigned bytes...
	 *  @return -- any of the helpParse.FORMATS
	 */
	protected int getFieldFormat() { return parseHelp.UNSIGNEDSHORT; }
	
	/** Set the format of printed lines in toString().
	 *  Also uses getFieldFormat() to find size of each element
	 *   and [un]signed format.
	 *  Default to eight hex bytes per line...
	 */
	/**  @return -- number of elements to print on a line
	protected int getFieldsPerLine() { return 8; }
	 */

	/**  @return -- print conversion base: 10 or 16
	protected int getPrintBase() { return 10; }
	 */
	
	/**  @return -- toString() print class and header if true
	protected boolean printHeader() { return true; }
	 */
	
	/** Return the max number of fields we can set/get in this message
	 *  Note: that this needs to be defined and executed in the
	 *   final message classes in order to get the right numbers.
	 *  
	 * @return number of message fields
	**/
	public int getNumFields() { return NUMFIELDS; }
	
} // end'o'TMUPICint
	