/** Count420Msg.java -- TOSComm Command and Status message for Mote.
 * 		Uses to CC2420 type message header for telosb.
**/
package com.etantdonnes.tinyos.demoMessage;

import com.etantdonnes.tinyos.*;


/** Message sent to and received from Mote
 * This message will be received as a raw buffer from the mote.
 *  The buffer will be stuck into the data area of this message class
 *  and then parsed appropriately.  
 **/
public class Count2420Msg  extends TMstub2420
{
	// the AM types that match this class
	public static final int AM_COUNTMSG = 4;
	public static final int PAYSIZE = 4;	// payload bytes in this packet
	private static final int NUMFIELDS = 2;	// number of parameters in message
	
	// extra components of the CountMsg itself
	public int count;
	public int source;

	/** Create a message with empty values
	 *    usually for received message wrapper
	 */
	public Count2420Msg()
	{
		super();
		header = new TMheader2420();
	}

	/** Create a message with specified GroupID and destination
	 * 		usually for send message
	 * @param gid	-- group ID
	 * @param dest	-- destination addr
	 */
	public Count2420Msg( int gid, int dest )
	{
		super();
		header = new TMheader2420( AM_COUNTMSG, PAYSIZE,
								   TMheader.BCASTADDR, gid );
		this.setDestAddr( dest );
	}

	/** Parse a message packet into our local fields.
	 *  @return -- new offset if OK
	 *  		   -1 if something wrong with packet.
	 *
	 * NOTE: all the offsets and sizes are hard coded here...
	 **/
	public int parseMessage()
	{
		// parse header and get the first byte of the payload area
		int s = super.parseMessage();
		if( s < 0 )		return s;
		
		// do the local values
		this.count		= parseHelp.ti(data, s); s+=2;
		this.source		= parseHelp.ti(data, s); s+=2;;

		return s;
	}
	
	/** Set local fields in given data buffer
	 *  @return -- new offset if OK
	 *  		   -1 if something wrong with packet.
	 *
	 * NOTE: all the offsets and sizes are hard coded here...
	 **/
	public int setMessage()
	{
		// set header and get the first byte of the payload area
		int s = super.setMessage();
		if( s < 0 )		return s;

		parseHelp.fi( count, data, s );  s+=2;
		parseHelp.fi( source, data, s ); s+=2;

		return s;
	}

	/** Set the local values to -1 -- The don't-set value
	 *    could implement, but why bother...
	 * @return nada
	public void nullFields()
	{
		return;
	}
	**/
	
	/** Get the number of fields we can set in this message
	 *  Note that this needs to be defined and executed in
	 *  the final message classes in order to get the right numbers.
	 *  
	 * @return number of parameters
	**/
	public int getNumFields() { return NUMFIELDS; }

	/** convert local message data to readable format
	 **/
	public String toString()
	{
		return( (printHeader() ?
				(// put in our class name
				 this.getClass().getSimpleName() + " -- " +
				 // and format header info
				 ((TMheader)header).toString() + "\n" )
				 : ("")) +
				"c=" + count +
				" s=" + source
			  );
	}
	
	/** convert local message data to pretty format
	 **/
	public String toPrettyString()
	{
		// fergit about the header printing....
		return(
				"Count:     " + count + "\n" +
				"Source:    " + source + "\n"
			  );
	}

} // end'o'Count2420Msg
